SELECT 'Upgrading MetaStore schema from 2.0.0 to 2.1.0' AS MESSAGE;

/******** HIVE-13076 ************/
IF NOT EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[KEY_CONSTRAINTS]') AND type in (N'U'))
BEGIN
CREATE TABLE [dbo].[KEY_CONSTRAINTS]
( 
  [CHILD_CD_ID] [bigint] NULL,
  [CHILD_INTEGER_IDX] [int] NULL,
  [CHILD_TBL_ID] [bigint] NULL,
  [PARENT_CD_ID] [bigint] NOT NULL,
  [PARENT_INTEGER_IDX] [int] NOT NULL,
  [PARENT_TBL_ID] [bigint] NOT NULL,
  [POSITION] [int] NOT NULL,
  [CONSTRAINT_NAME] [varchar](400) NOT NULL,
  [CONSTRAINT_TYPE] [smallint] NOT NULL,
  [UPDATE_RULE] [smallint] NULL,
  [DELETE_RULE] [smallint] NULL,
  [ENABLE_VALIDATE_RELY] [smallint] NOT NULL
CONSTRAINT [CONSTRAINTS_PK] PRIMARY KEY CLUSTERED
(
  [CONSTRAINT_NAME] ASC,
  [POSITION] ASC
) WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
)
END 

/****** Adding index for KEY_CONSTRAINTS ******/
IF NOT EXISTS(SELECT * FROM sys.indexes WHERE name = 'KEY_CONSTRAINTS_N49' AND object_id = OBJECT_ID('KEY_CONSTRAINTS'))
BEGIN
CREATE NONCLUSTERED INDEX KEY_CONSTRAINTS_N49
ON [dbo].[KEY_CONSTRAINTS] ([PARENT_TBL_ID])
END

/******** HIVE-13395 ************/
IF NOT EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[WRITE_SET]') AND type in (N'U'))
BEGIN
CREATE TABLE [dbo].[WRITE_SET] (
  [WS_DATABASE] [nvarchar](128) NOT NULL,
  [WS_TABLE] [nvarchar](128) NOT NULL,
  [WS_PARTITION] [nvarchar](767) NULL,
  [WS_TXNID] [bigint] NOT NULL,
  [WS_COMMIT_ID] [bigint] NOT NULL,
  [WS_OPERATION_TYPE] [char](1) NOT NULL
)
END

ALTER TABLE [dbo].[TXN_COMPONENTS] ADD [TC_OPERATION_TYPE] [char](1) NULL;

/******** HIVE-13354 ************/

ALTER TABLE [dbo].[COMPACTION_QUEUE] ADD [CQ_TBLPROPERTIES] [nvarchar](2048) NULL;
ALTER TABLE [dbo].[COMPLETED_COMPACTIONS] ADD [CC_TBLPROPERTIES] [nvarchar](2048) NULL;


UPDATE [dbo].[VERSION] SET SCHEMA_VERSION='2.1.0', VERSION_COMMENT='Hive release version 2.1.0' where VER_ID=1;
SELECT 'Finished upgrading MetaStore schema from 2.0.0 to 2.1.0' AS MESSAGE;
